Stan Math Library: stan/math/prim/mat/fun/cholesky_corr_constrain.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
cholesky_corr_constrain.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/scal/fun/log1m.hpp>`
`#include <stan/math/prim/scal/fun/square.hpp>`
`#include <stan/math/prim/scal/fun/corr_constrain.hpp>`
`#include <cmath>`
`#include <iostream>`
`#include <stdexcept>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > | stan::math::cholesky_corr_constrain (const Eigen::Matrix< T, Eigen::Dynamic, 1 > &y, int K)
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > | stan::math::cholesky_corr_constrain (const Eigen::Matrix< T, Eigen::Dynamic, 1 > &y, int K, T &lp)

[ Stan Home Page ] © 2011–2016, Stan Development Team.